@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2014, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -36,11 +36,11 @@
  *      {@link java.nio.file.FileSystems#newFileSystem
  *      FileSystems.newFileSystem(URI.create("jrt:/"))}.
  *      </dd>
- * <dt class="simpleTagLabel" style="font-family:'DejaVu Sans', Arial, Helvetica, sans serif">Tool Guides:</dt>
- * <dd style="font-family:'DejaVu Sans', Arial, Helvetica, sans serif"> {@extLink java_tool_reference java launcher},
- *      {@extLink keytool_tool_reference keytool}</dd>
  * </dl>
  *
+ * @toolGuide java java launcher
+ * @toolGuide keytool
+ *
  * @provides java.nio.file.spi.FileSystemProvider
  *
  * @uses java.lang.System.LoggerFinder
@@ -75,8 +75,6 @@
  * @since 9
  */
 module java.base {
-    // source file: file:///scratch/opt/mach5/mesos/work_dir/slaves/dd0bab7c-a530-4905-bb6b-daa7153eb2c1-S60/frameworks/1735e8a2-a1db-478c-8104-60c8b0af87dd-0196/executors/7b9bbb18-6977-45a8-a8b3-112df32bb32b/runs/25f688c6-97bf-45a5-8e15-c185b0836da4/workspace/open/src/java.base/share/classes/module-info.java
-    //              file:///scratch/opt/mach5/mesos/work_dir/slaves/dd0bab7c-a530-4905-bb6b-daa7153eb2c1-S60/frameworks/1735e8a2-a1db-478c-8104-60c8b0af87dd-0196/executors/7b9bbb18-6977-45a8-a8b3-112df32bb32b/runs/25f688c6-97bf-45a5-8e15-c185b0836da4/workspace/open/src/java.base/unix/classes/module-info.java.extra
     exports java.io;
     exports java.lang;
     exports java.lang.annotation;
@@ -85,6 +83,7 @@ module java.base {
     exports java.lang.module;
     exports java.lang.ref;
     exports java.lang.reflect;
+    exports java.lang.runtime;
     exports java.math;
     exports java.net;
     exports java.net.spi;
@@ -97,7 +96,6 @@ module java.base {
     exports java.nio.file.attribute;
     exports java.nio.file.spi;
     exports java.security;
-    exports java.security.acl;
     exports java.security.cert;
     exports java.security.interfaces;
     exports java.security.spec;
@@ -130,15 +128,21 @@ module java.base {
     exports javax.security.auth.x500;
     exports javax.security.cert;
     exports com.sun.security.ntlm to java.security.sasl;
-    exports jdk.internal to jdk.jfr;
+    exports jdk.internal to
+        java.compiler,
+        jdk.compiler,
+        jdk.jfr,
+        jdk.jshell;
     exports jdk.internal.access to
         java.desktop,
         java.logging,
         java.management,
         java.naming,
         java.rmi,
+        jdk.incubator.foreign,
         jdk.jlink,
         jdk.net;
+    exports jdk.internal.access.foreign to jdk.incubator.foreign;
     exports jdk.internal.event to jdk.jfr;
     exports jdk.internal.jimage to jdk.jlink;
     exports jdk.internal.jimage.decompressor to jdk.jlink;
@@ -161,15 +165,18 @@ module java.base {
         jdk.attach,
         jdk.charsets,
         jdk.compiler,
+        jdk.incubator.foreign,
         jdk.internal.vm.ci,
         jdk.jfr,
         jdk.jshell,
+        jdk.nio.mapmode,
         jdk.scripting.nashorn,
         jdk.scripting.nashorn.shell,
         jdk.unsupported;
     exports jdk.internal.module to
         java.instrument,
         java.management.rmi,
+        jdk.incubator.jpackage,
         jdk.jartool,
         jdk.jfr,
         jdk.jlink;
@@ -194,12 +201,14 @@ module java.base {
         java.management,
         jdk.internal.jvmstat,
         jdk.management.agent;
+    exports jdk.internal.platform to jdk.management;
     exports jdk.internal.ref to java.desktop;
     exports jdk.internal.reflect to
         java.logging,
         java.sql,
         java.sql.rowset,
         jdk.dynalink,
+        jdk.internal.vm.ci,
         jdk.scripting.nashorn,
         jdk.unsupported;
     exports jdk.internal.util.jar to jdk.jartool;
@@ -211,6 +220,9 @@ module java.base {
     exports jdk.internal.vm.annotation to
         jdk.internal.vm.ci,
         jdk.unsupported;
+    exports sun.invoke.util to
+        jdk.compiler,
+        jdk.incubator.foreign;
     exports sun.net to
         java.net.http,
         jdk.naming.dns;
@@ -221,7 +233,8 @@ module java.base {
     exports sun.net.util to
         java.desktop,
         java.net.http,
-        jdk.jconsole;
+        jdk.jconsole,
+        jdk.sctp;
     exports sun.net.www to
         java.net.http,
         jdk.jartool;
@@ -229,6 +242,7 @@ module java.base {
     exports sun.nio.ch to
         java.management,
         jdk.crypto.cryptoki,
+        jdk.incubator.foreign,
         jdk.net,
         jdk.sctp;
     exports sun.nio.cs to
@@ -245,7 +259,8 @@ module java.base {
         java.sql.rowset;
     exports sun.security.action to
         java.desktop,
-        java.security.jgss;
+        java.security.jgss,
+        jdk.incubator.foreign;
     exports sun.security.internal.interfaces to jdk.crypto.cryptoki;
     exports sun.security.internal.spec to jdk.crypto.cryptoki;
     exports sun.security.jca to
