@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -134,14 +134,6 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                "Australian Central Time (Northern Territory)",
                "ACT",
             };
-        final String[] JRE_Asia_Qostanay = new String[] {
-               "Qostanay Time",
-               "GMT+06:00",
-               "Qostanay Summer Time",
-               "GMT+06:00",
-               "Qostanay Time",
-               "GMT+06:00",
-            };
         final String[] Lord_Howe = new String[] {
                "Lord Howe Standard Time",
                "LHST",
@@ -358,14 +350,6 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                "Falkland Islands Time",
                "FKT",
             };
-        final String[] Bhutan = new String[] {
-               "Bhutan Time",
-               "BTT",
-               "Bhutan Summer Time",
-               "BTST",
-               "Bhutan Time",
-               "BTT",
-            };
         final String[] Apia = new String[] {
                "Apia Standard Time",
                "WSST",
@@ -374,6 +358,14 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                "Apia Time",
                "WST",
             };
+        final String[] Bhutan = new String[] {
+               "Bhutan Time",
+               "BTT",
+               "Bhutan Summer Time",
+               "BTST",
+               "Bhutan Time",
+               "BTT",
+            };
         final String[] Nauru = new String[] {
                "Nauru Time",
                "NRT",
@@ -382,6 +374,14 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                "Nauru Time",
                "NRT",
             };
+        final String[] JRE_Africa_El_Aaiun = new String[] {
+               "Western European Time",
+               "WET",
+               "Western European Summer Time",
+               "WEST",
+               "Western European Time",
+               "WET",
+            };
         final String[] Kazakhstan_Western = new String[] {
                "West Kazakhstan Time",
                "AQTT",
@@ -495,12 +495,12 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                "VET",
             };
         final String[] JRE_Europe_Istanbul = new String[] {
-               "Eastern European Time",
-               "EET",
-               "Eastern European Summer Time",
-               "EEST",
-               "Eastern European Time",
-               "EET",
+               "Turkey Time",
+               "TRT",
+               "Turkey Summer Time",
+               "TRST",
+               "Turkey Time",
+               "TRT",
             };
         final String[] Phoenix_Islands = new String[] {
                "Phoenix Islands Time",
@@ -598,6 +598,14 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                "French Southern & Antarctic Lands Time",
                "TFT",
             };
+        final String[] JRE_Africa_Casablanca = new String[] {
+               "Western European Time",
+               "WET",
+               "Western European Summer Time",
+               "WEST",
+               "Western European Time",
+               "WET",
+            };
         final String[] New_Caledonia = new String[] {
                "New Caledonia Standard Time",
                "NCT",
@@ -718,13 +726,13 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                "Bougainville Time",
                "BT",
             };
-        final String[] Colombia = new String[] {
-               "Colombia Standard Time",
-               "COT",
-               "Colombia Summer Time",
-               "COST",
-               "Colombia Time",
-               "COT",
+        final String[] Australia_Eastern = new String[] {
+               "Australian Eastern Standard Time",
+               "AEST",
+               "Australian Eastern Daylight Time",
+               "AEDT",
+               "Eastern Australia Time",
+               "AET",
             };
         final String[] French_Guiana = new String[] {
                "French Guiana Time",
@@ -734,13 +742,13 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                "French Guiana Time",
                "GFT",
             };
-        final String[] Australia_Eastern = new String[] {
-               "Australian Eastern Standard Time",
-               "AEST",
-               "Australian Eastern Daylight Time",
-               "AEDT",
-               "Eastern Australia Time",
-               "AET",
+        final String[] Colombia = new String[] {
+               "Colombia Standard Time",
+               "COT",
+               "Colombia Summer Time",
+               "COST",
+               "Colombia Time",
+               "COT",
             };
         final String[] Chile = new String[] {
                "Chile Standard Time",
@@ -807,12 +815,12 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                "AMT",
             };
         final String[] JRE_Turkey = new String[] {
-               "Eastern European Time",
-               "EET",
-               "Eastern European Summer Time",
-               "EEST",
-               "Eastern European Time",
-               "EET",
+               "Turkey Time",
+               "TRT",
+               "Turkey Summer Time",
+               "TRST",
+               "Turkey Time",
+               "TRT",
             };
         final String[] Africa_Central = new String[] {
                "Central Africa Time",
@@ -878,14 +886,6 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                "Paraguay Time",
                "PYT",
             };
-        final String[] Casey = new String[] {
-               "Casey Time",
-               "AWST",
-               "Australian Western Daylight Time",
-               "AWDT",
-               "Australian Western Time",
-               "AWT",
-            };
         final String[] Malaysia = new String[] {
                "Malaysia Time",
                "MYT",
@@ -1334,21 +1334,21 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                "South Georgia Time",
                "GT",
             };
-        final String[] JRE_Asia_Istanbul = new String[] {
-               "Eastern European Time",
-               "EET",
-               "Eastern European Summer Time",
-               "EEST",
-               "Eastern European Time",
-               "EET",
+        final String[] Volgograd = new String[] {
+               "Volgograd Standard Time",
+               "MSK",
+               "Volgograd Summer Time",
+               "MSD",
+               "Volgograd Time",
+               "MT",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Northwest Mexico Standard Time",
-               "PST",
-               "Northwest Mexico Daylight Time",
-               "PDT",
-               "Northwest Mexico Time",
-               "PT",
+        final String[] JRE_Asia_Istanbul = new String[] {
+               "Turkey Time",
+               "TRT",
+               "Turkey Summer Time",
+               "TRST",
+               "Turkey Time",
+               "TRT",
             };
         final String[] Easter = new String[] {
                "Easter Island Standard Time",
@@ -1358,6 +1358,14 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                "Easter Island Time",
                "EAST",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "Northwest Mexico Standard Time",
+               "PST",
+               "Northwest Mexico Daylight Time",
+               "PDT",
+               "Northwest Mexico Time",
+               "PT",
+            };
         final String[] DumontDUrville = new String[] {
                "Dumont-d\u2019Urville Time",
                "DDUT",
@@ -1518,14 +1526,6 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
                "Samara Time",
                "SAMT",
             };
-        final String[] Pyongyang = new String[] {
-               "Pyongyang Time",
-               "KST",
-               "Korea Daylight Time",
-               "KDT",
-               "Korea Time",
-               "KT",
-            };
         final String[] India = new String[] {
                "India Standard Time",
                "IST",
@@ -1565,7 +1565,7 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca", JRE_Africa_Casablanca },
             { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
@@ -1632,16 +1632,7 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             { "Antarctica/Davis", Davis },
             { "Antarctica/McMurdo", New_Zealand },
             { "America/Argentina/Mendoza", Argentina },
-            { "HST",
-                new String[] {
-                    "Hawaii Standard Time",
-                    "HST",
-                    "Hawaii Daylight Time",
-                    "HDT",
-                    "Hawaii Time",
-                    "HST",
-                }
-            },
+            { "HST", JRE_HST },
             { "Pacific/Tahiti", Tahiti },
             { "Africa/Asmera", Africa_Eastern },
             { "Europe/Busingen", Europe_Central },
@@ -1737,7 +1728,7 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             { "America/Antigua", Atlantic },
             { "Pacific/Gambier", Gambier },
             { "Africa/Gaborone", Africa_Central },
-            { "Asia/Pyongyang", Pyongyang },
+            { "Asia/Pyongyang", Korea },
             { "Etc/Universal",
                 new String[] {
                     "Coordinated Universal Time",
@@ -1751,7 +1742,7 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Etc/Unknown", "Unknown City" },
             { "Canada/Newfoundland", Newfoundland },
-            { "Asia/Qyzylorda", Kazakhstan_Eastern },
+            { "Asia/Qyzylorda", Kazakhstan_Western },
             { "America/Yakutat", Alaska },
             { "Africa/Asmara", Africa_Eastern },
             { "Europe/Vienna", Europe_Central },
@@ -1815,7 +1806,7 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             { "SystemV/CST6", America_Central },
             { "Asia/Vladivostok", Vladivostok },
             { "Africa/Maputo", Africa_Central },
-            { "Africa/El_Aaiun", Europe_Western },
+            { "Africa/El_Aaiun", JRE_Africa_El_Aaiun },
             { "Africa/Ouagadougou", GMT },
             { "America/Cayman", America_Eastern },
             { "Asia/Ulaanbaatar", Mongolia },
@@ -1944,6 +1935,7 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             { "America/Caracas", Venezuela },
             { "Asia/Hebron", Europe_Eastern },
             { "SystemV/PST8PDT", America_Pacific },
+            { "timezone.excity.Asia/Qostanay", "Kostanay" },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "America/North_Dakota/New_Salem", America_Central },
@@ -2056,7 +2048,7 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             { "Asia/Beirut", Europe_Eastern },
             { "Pacific/Bougainville", JRE_Pacific_Bougainville },
             { "US/Central", America_Central },
-            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "Asia/Yakutsk", Yakutsk },
             { "Pacific/Galapagos", Galapagos },
@@ -2071,7 +2063,7 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "Africa/Djibouti", Africa_Eastern },
             { "EST", America_Eastern },
-            { "Asia/Qostanay", JRE_Asia_Qostanay },
+            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
@@ -2091,7 +2083,7 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             { "Atlantic/Faeroe", Europe_Western },
             { "America/Kentucky/Louisville", America_Eastern },
             { "Asia/Ho_Chi_Minh", Indochina },
-            { "Antarctica/Casey", Casey },
+            { "Antarctica/Casey", Australia_Western },
             { "Europe/Copenhagen", Europe_Central },
             { "Atlantic/Azores", Azores },
             { "ROK", Korea },
@@ -2247,7 +2239,7 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             { "Canada/Mountain", America_Mountain },
             { "Australia/Brisbane", Australia_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
-            { "Europe/Volgograd", Moscow },
+            { "Europe/Volgograd", Volgograd },
             { "America/Lower_Princes", Atlantic },
             { "America/Rio_Branco", Acre },
             { "America/Danmarkshavn", GMT },
@@ -2269,6 +2261,7 @@ public class TimeZoneNames_en extends TimeZoneNamesBundle {
             { "Africa/Bissau", GMT },
             { "Asia/Tehran", Iran },
             { "WET", JRE_WET },
+            { "timezone.excity.Europe/Kiev", "Kiev" },
             { "Etc/Greenwich", GMT },
             { "America/Ensenada", America_Pacific },
             { "Pacific/Midway", Samoa },
